@@ -10,12 +10,11 @@ from spatial_measure import Global_L, Local_L
 import numpy as np
 import seaborn as sns
 from matplotlib import pyplot as plt
-from plot import plotting as pl
 from modules import gmod
 
-def load_raw(sg, count_path, meta_path , visium_path):
+def load_raw(self, count_path, meta_path , visium_path):
     if os.path.exists(visium_path):
-            sg.visium_path = visium_path
+            self.visium_path = visium_path
             data = sc.read_visium(visium_path)
     elif os.path.exists(count_path) and os.path.exists(meta_path):
         count = pd.read_csv(count_path, index_col=0)
@@ -37,12 +36,12 @@ def load_raw(sg, count_path, meta_path , visium_path):
 
     return data
 
-def process_st(sg,data, min_counts=150, min_cells=10):
+def process_st(self,data, min_counts=150, min_cells=10):
     data.var_names_make_unique()
     data.var_names = data.var_names.to_series().apply(lambda x: str(x).upper())
     sc.pp.filter_cells(data, min_counts=min_counts)
     sc.pp.filter_genes(data, min_cells=min_cells)
-    sg.raw_adata = data.copy()
+    self.raw_adata = data.copy()
     sc.pp.normalize_total(data, target_sum=10**6)
     sc.pp.log1p(data)
     return data
@@ -56,8 +55,8 @@ def spatial_process(data):
     data.var['moranI'] = data.uns['moranI']['I'].copy()
     return data
 
-def spatial_pattern_genes(sg, I=None, topK=None):
-    adata = sg.adata.copy()
+def spatial_pattern_genes(self, I=None, topK=None):
+    adata = self.adata.copy()
     if I is None and topK is None:
         GM = GaussianMixture(n_components=2, covariance_type='spherical')
         GM.fit(np.reshape(adata.var.moranI.to_numpy(), (adata.shape[1], 1)))
@@ -79,11 +78,11 @@ def spatial_pattern_genes(sg, I=None, topK=None):
                     hue='high_pattern_genes',
                     palette={True: "red", False: "lightgray"},ax=ax)
     plt.close()
-    sg.histI = f
-    sg.adata = adata
+    self.histI = f
+    self.adata = adata
     return f
 
-def spatial_association(sg, grouped_only=True, use_pattern_genes=True,
+def spatial_association(self, grouped_only=True, use_pattern_genes=True,
                         genes=None, n_permutation=99, 
                         FDR_cutoff = 0.05, L_cutoff = 0.1):
     """ Calculate spatial associations
@@ -99,10 +98,10 @@ def spatial_association(sg, grouped_only=True, use_pattern_genes=True,
         
         Return:
         ----------
-        The spatial correlation data frame will be saved to sg.co_expression.   
+        The spatial correlation data frame will be saved to self.co_expression.   
     """
     if grouped_only:
-        grouped_data = sg.grouped_adata.copy()
+        grouped_data = self.grouped_adata.copy()
         grouped_data = Global_L(grouped_data, permutations=n_permutation, percent=0.2, max_RAM=32)
         df = grouped_data.uns['co_expression'].copy()
         df['pair'] = df.gene_1 + "&" + df.gene_2
@@ -116,15 +115,15 @@ def spatial_association(sg, grouped_only=True, use_pattern_genes=True,
         df["Association"] = "NS"
         df.loc[(df['L.FDR'] <= FDR_cutoff) & (df['L'] >= L_cutoff), "Association"] = "SigPos"
         df.loc[(df['L.FDR'] <= FDR_cutoff) & (df['L'] <= -L_cutoff), "Association"] = "SigNeg"
-        sg.co_expression_grouped = df
+        self.co_expression_grouped = df
         return
     
     if use_pattern_genes:
-        adata = sg.adata[:, sg.adata.var.high_pattern_genes].copy()         
+        adata = self.adata[:, self.adata.var.high_pattern_genes].copy()         
     elif genes is not None:
-        adata = sg.adata[:, genes].copy()
+        adata = self.adata[:, genes].copy()
     else:
-        adata = sg.adata.copy()
+        adata = self.adata.copy()
 
     try:
         adata.X = adata.X.toarray()
@@ -147,14 +146,14 @@ def spatial_association(sg, grouped_only=True, use_pattern_genes=True,
     df["Association"] = "NS"
     df.loc[(df['L.FDR'] <= FDR_cutoff) & (df['L'] >= L_cutoff), "Association"] = "SigPos"
     df.loc[(df['L.FDR'] <= FDR_cutoff) & (df['L'] <= -L_cutoff), "Association"] = "SigNeg"
-    sg.co_expression = df
+    self.co_expression = df
 
-def group_adata_by_genes(sg, ct_dict = None, inplace=True):
-    ## Overwrite sg.co_expression_grouped object if existed.
-    if sg.co_expression_grouped is not None:
-        sg.co_expression_grouped = None
+def group_adata_by_genes(self, ct_dict = None, inplace=True):
+    ## Overwrite self.co_expression_grouped object if existed.
+    if self.co_expression_grouped is not None:
+        self.co_expression_grouped = None
 
-    data = sg.raw_adata.copy()
+    data = self.raw_adata.copy()
     sc.pp.normalize_total(data, target_sum=10**6)
     pool_genes = data.var_names.tolist()
 
@@ -207,49 +206,37 @@ def group_adata_by_genes(sg, ct_dict = None, inplace=True):
         n_jobs=1)
 
     if inplace:
-        sg.ct_dict = ct_dict
-        sg.grouped_adata=data
-        spatial_association(sg, grouped_only=True)
+        self.ct_dict = ct_dict
+        self.grouped_adata=data
+        spatial_association(self, grouped_only=True)
     else:
         return data
 
-def save_modules(sg, path):
-    sg.module_dict['module_df'].to_csv(path)
+def save_modules(self, path):
+    self.module_dict['module_df'].to_csv(path)
 
-def save_coexpr(sg, path, use_grouped=False):
+def save_coexpr(self, path, use_grouped=False):
     if use_grouped:
-        sg.co_expression_grouped.to_csv(path)
+        self.co_expression_grouped.to_csv(path)
     else:
-        sg.co_expression.to_csv(path)
+        self.co_expression.to_csv(path)
 
-def hotspot(sg, var_1, var_2, dropout_rm=True, use_grouped=False, cmap='viridis', alpha_img=0.5):
-    return pl.hotspot(sg, var_1, var_2, dropout_rm=dropout_rm, use_grouped=use_grouped, cmap=cmap, alpha_img=alpha_img)
+def gene_modules(self, nmax=6, use_grouped=False, n_modules = None):
+    return gmod.genemodules(self, nmax=nmax, use_grouped=use_grouped, n_modules = n_modules)
 
-def volcano(sg, FDR_cutoff=0.05, L_cutoff=0.1, use_grouped=False):
-    return pl.volcano(sg, FDR_cutoff=FDR_cutoff, L_cutoff=L_cutoff, use_grouped=use_grouped)
-
-def clustermap(sg, figsize=(6,6), use_grouped=False):
-    return pl.clustermap(sg, figsize=figsize, use_grouped=use_grouped)
-
-def module_hotspot(sg, dropout_rm=True, alpha_img=0.5, cmap='Blues_r', ncols=4):
-    return pl.module_hotspot(sg, dropout_rm=dropout_rm, alpha_img=alpha_img, cmap=cmap, ncols=ncols)
-
-def gene_modules(sg, nmax=6, use_grouped=False, n_modules = None):
-    return gmod.genemodules(sg, nmax=nmax, use_grouped=use_grouped, n_modules = n_modules)
-
-def module_pattern(sg, ncols=4, alpha_img=0.5, cmap='Reds'):
-    mod2gene = sg.module_dict['mod2gene'].copy()
+def module_pattern(self, ncols=4, alpha_img=0.5, cmap='Reds'):
+    mod2gene = self.module_dict['mod2gene'].copy()
     modules = list(mod2gene.keys())
-    adata = group_adata_by_genes(sg, ct_dict=mod2gene, inplace=False)
+    adata = group_adata_by_genes(self, ct_dict=mod2gene, inplace=False)
 
     adata.obs.rename(columns={"ct": "module"}, inplace=True)
     sc.pl.spatial(adata, color=modules, alpha_img=alpha_img, ncols=ncols, cmap=cmap)
 
-def module_hotspot(sg, dropout_rm=True, alpha_img=0.5, cmap='Blues_r', ncols=4):
-    mod2gene = sg.module_dict['mod2gene'].copy()
+def module_hotspot(self, dropout_rm=True, alpha_img=0.5, cmap='Blues_r', ncols=4):
+    mod2gene = self.module_dict['mod2gene'].copy()
     modules = list(mod2gene.keys())
     n_modules = len(modules)
-    adata = group_adata_by_genes(sg, ct_dict=mod2gene, inplace=False)
+    adata = group_adata_by_genes(self, ct_dict=mod2gene, inplace=False)
     adata.obs.rename(columns={"ct": "module"}, inplace=True)
 
     # f, axs = plt.subplots(n_modules,n_modules, figsize=(4*n_modules,4*n_modules))
