@@ -1,14 +1,15 @@
-import scanpy as sc
-import anndata as ad
-import squidpy as sq
-import pandas as pd
-import seaborn as sns
-import numpy as np
+# import scanpy as sc
+# import anndata as ad
+# import squidpy as sq
+# import pandas as pd
+# import seaborn as sns
+# import numpy as np
 import warnings
 from matplotlib import pyplot as plt
 warnings.filterwarnings("ignore")
-from _utils import *
-
+from ._utils import *
+from ._gmod import *
+from ._plotting import *
 
 class SG(object):
     """ Spatial Enrichment Analysis of Gene Association using L-index.
@@ -17,6 +18,8 @@ class SG(object):
                  count_path = "", meta_path = "",
                  visium_path="/mnt/atlas_local/linhua/data/SEAGAL/test_data/"):
         
+
+
         data = load_raw(self, count_path, meta_path, visium_path)
             
         ## preprocess, and QC
@@ -28,7 +31,9 @@ class SG(object):
         self.hotspot = None
         self.hotspot_names = None
         # self.plot =  plot()
-    
+
+
+
 
 
 
